@@ -48,10 +48,16 @@ CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"], max_content_width=15
 help_message = """This tool include a bunch of useful commands:\n
 \b
 1. Google Driver downloader
-2. more to come...
+2. Send message to Slack
+3. more to come...
 """
 
-main = MyCLI(help=help_message, context_settings=CONTEXT_SETTINGS)
+main = MyCLI(
+    help=help_message,
+    context_settings=CONTEXT_SETTINGS,
+    subcommand_metavar="<command>",
+    options_metavar="[options]",
+)
 
 if __name__ == "__main__":
     main()
